A TransitionLayer of the Great Lakes that only prevents transition over land
Source: R/data.r
greatLakesTrLayer.RdA TransitionLayer object that only allows transitions to occur within water (i.e., prohibits movement onto land).
Details
This dataset was developed for non-linear interpolation of fish movement paths from telemetry data and is used by default in interpolate_path.
Created from great_lakes_polygon; see 'data-raw/data-greatLakesTrLayer.r'.