Loads the OTN tagging metadata sheet to prepare it for use in convert_otn_to_att
Source: R/load-prepare_tag_sheet.R
prepare_tag_sheet.RdLoads the OTN tagging metadata sheet to prepare it for use in
convert_otn_to_att
Details
The function takes the path to the tagging sheet, what line to start
reading the headers from, and what sheet in the excel file to use. It converts column names
to be used by convert_otn_to_att.
Examples
#--------------------------------------------------
# EXAMPLE #1 - loading from NSBS tagging
library(glatos)
tag_path <- system.file("extdata", "otn_nsbs_tag_metadata.xls",
package = "glatos"
)
tags <- prepare_tag_sheet(tag_path, 5, 2)