Skip to contents

Sample detection range data set from Lake Superior.

Usage

range_detection

Format

A data frame with 58309 rows and 30 variables

F. Zomer, T. Hayden

Details

Data from a stationary detection range test conducted in 2018. Data are in standard GLATOS detection export format and are intened to accompany detecton range analysis vignette.