Loads the OTN receiver deployment metadata sheet to prepare it for use in convert_otn_to_att
Source: R/load-prepare_deploy_sheet.R
prepare_deploy_sheet.RdLoads the OTN receiver deployment metadata sheet to prepare it for use in
convert_otn_to_att
Details
The function takes the path to the deployment sheet, what line to start
reading from, and what sheet in the excel file to use. It converts column names
to be used by convert_otn_to_att.
Examples
#--------------------------------------------------
# EXAMPLE #1 - loading from NSBS simplified Deployments
library(glatos)
deploy_path <- system.file("extdata", "hfx_deploy_simplified.xlsx",
package = "glatos"
)
deploy <- prepare_deploy_sheet(deploy_path,
header_line = 1,
sheet_name = 1
)